//! A small set of utilities.

mod input;
pub use self::input::*;

mod rand;
pub use self::rand::*;
